@@ -219,11 +219,6 @@ rebuild_record()
  * set_record:
  * setup $0, but defer parsing rest of line until reference is made to $(>0)
  * or to NF.  At that point, parse only as much as necessary.
- *
- * Manage a private buffer for the contents of $0.  Doing so keeps us safe
- * if `getline var' decides to rearrange the contents of the IOBUF that
- * $0 might have been pointing into.  The cost is the copying of the buffer;
- * but better correct than fast.
  */
 void
 set_record(buf, cnt, freeold)
@@ -233,10 +228,6 @@ int freeold;
 {
 	register int i;
 	NODE *n;
-	static char *databuf;
-	static unsigned long databuf_size;
-#define INITIAL_SIZE	512
-#define MAX_SIZE	((unsigned long) ~0)	/* maximally portable ... */
 
 	NF = -1;
 	for (i = 1; i <= parse_high_water; i++) {
@@ -257,24 +248,9 @@ int freeold;
 		save_FS = dupnode(FS_node->var_value);
 	}
 	if (freeold) {
-		/* buffer management: */
-		if (databuf_size == 0) {	/* first time */
-			emalloc(databuf, char *, INITIAL_SIZE, "set_record");
-			databuf_size = INITIAL_SIZE;
-		}
-		/* make sure there's enough room */
-		if (cnt > databuf_size) {
-			while (cnt > databuf_size && databuf_size <= MAX_SIZE)
-				databuf_size *= 2;
-			erealloc(databuf, char *, databuf_size, "set_record");
-		}
-		/* copy the data */
-		memcpy(databuf, buf, cnt);
-
-		/* manage field 0: */
 		unref(fields_arr[0]);
 		getnode(n);
-		n->stptr = databuf;
+		n->stptr = buf;
 		n->stlen = cnt;
 		n->stref = 1;
 		n->type = Node_val;
@@ -284,9 +260,6 @@ int freeold;
 	}
 	fields_arr[0]->flags |= MAYBE_NUM;
 	field0_valid = TRUE;
-
-#undef INITIAL_SIZE
-#undef MAX_SIZE
 }
 
 /* reset_record --- start over again with current $0 */
